@@ -133,7 +133,11 @@ class dyn_obj:
         bpy.context.collection.objects.link(int_curveOB)
         
         int_curveOB.data.bevel_depth = thickness
-        
+        int_curveOB.data.use_fill_caps = True
+
+
+        int_curveOB.data.bevel_factor_start = 0
+
         if staticity == 'dynamic':
             for i in range(len(frames)):
                 cur_frame = frames[i]
